-- *********************************************************************************************************************
-- *                           (c) 2013 by White Elephant GmbH, Schaffhausen, Switzerland                              *
-- *                                               www.white-elephant.ch                                               *
-- *                                                                                                                   *
-- *    This program is free software; you can redistribute it and/or modify it under the terms of the GNU General     *
-- *    Public License as published by the Free Software Foundation; either version 2 of the License, or               *
-- *    (at your option) any later version.                                                                            *
-- *                                                                                                                   *
-- *    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the     *
-- *    implied warranty of MERCHANTABILITY or FITNESS for A PARTICULAR PURPOSE. See the GNU General Public License    *
-- *    for more details.                                                                                              *
-- *                                                                                                                   *
-- *    You should have received a copy of the GNU General Public License along with this program; if not, write to    *
-- *    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.                *
-- *********************************************************************************************************************
-->Style: White_Elephant

with Win;
with System;

package Npp with Pure => True is

  -------------
  -- Messages
  -------------

  M_FIRST : constant := Win.WM_USER + 1000;

  M_SETSTATUSBAR        : constant := M_FIRST + 24;
    STATUSBAR_DOC_TYPE     : constant := 0;
    STATUSBAR_DOC_SIZE     : constant := 1;
    STATUSBAR_CUR_POS      : constant := 2;
    STATUSBAR_EOF_FORMAT   : constant := 3;
    STATUSBAR_UNICODE_TYPE : constant := 4;
    STATUSBAR_TYPING_MODE  : constant := 5;

  M_DMMREGASDCKDLG : constant := M_FIRST + 33;

  M_ADDTOOLBARICON : constant := M_FIRST + 41;

  type Toolbar_Icons is record
    Bmp  : Win.HBITMAP := System.Null_Address;
    Icon : Win.HICON   := System.Null_Address;
  end record
  with
    Alignment  => Win.Alignment,
    Convention => C,
    Pack       => True;

  No_Toolbar : constant Toolbar_Icons := (others => <>);

  RUNCOMMAND_USER      : constant := Win.WM_USER + 3000;
    VAR_NOT_RECOGNIZED : constant := 0;
    FULL_CURRENT_PATH  : constant := 1;
    CURRENT_DIRECTORY  : constant := 2;
    FILE_NAME          : constant := 3;
    NAME_PART          : constant := 4;
    EXT_PART           : constant := 5;
    CURRENT_WORD       : constant := 6;
    NPP_DIRECTORY      : constant := 7;

  M_GETFULLCURRENTPATH  : constant := RUNCOMMAND_USER + FULL_CURRENT_PATH;
  M_GETCURRENTDIRECTORY : constant := RUNCOMMAND_USER + CURRENT_DIRECTORY;
  M_GETFILENAME         : constant := RUNCOMMAND_USER + FILE_NAME;
  M_GETNAMEPART         : constant := RUNCOMMAND_USER + NAME_PART;
  M_GETEXTPART          : constant := RUNCOMMAND_USER + EXT_PART;
  M_GETCURRENTWORD      : constant := RUNCOMMAND_USER + CURRENT_WORD;
  M_GETNPPDIRECTORY     : constant := RUNCOMMAND_USER + NPP_DIRECTORY;


  ------------------
  -- Notifications
  ------------------

  N_FIRST : constant := 1000;

  N_READY : constant := N_FIRST + 1;
  -- To notify plugins that all the procedures of launchment of notepad++ are done.
  -- Scintilla.Notification->Nmhdr.Code = N_READY;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = 0;

  N_TBMODIFICATION : constant := N_FIRST + 2;
  -- To notify plugins that toolbar icons can be registered
  -- Scintilla.Notification->Nmhdr.Code = N_TB_MODIFICATION;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = 0;

  N_FILEBEFORECLOSE : constant := N_FIRST + 3;
  -- To notify plugins that the current file is about to be closed
  -- Scintilla.Notification->Nmhdr.Code = N_FILEBEFORECLOSE;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = BufferID;

  N_FILEOPENED : constant := N_FIRST + 4;
  -- To notify plugins that the current file is just opened
  -- Scintilla.Notification->Nmhdr.Code = N_FILEOPENED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = BufferID;

  N_FILECLOSED : constant := N_FIRST + 5;
  -- To notify plugins that the current file is just closed
  -- Scintilla.Notification->Nmhdr.Code = N_FILECLOSED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = BufferID;

  N_FILEBEFOREOPEN : constant := N_FIRST + 6;
  -- To notify plugins that the current file is about to be opened
  -- Scintilla.Notification->Nmhdr.Code = N_FILEBEFOREOPEN;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = BufferID;

  N_FILEBEFORESAVE : constant := N_FIRST + 7;
  -- To notify plugins that the current file is about to be saved
  -- Scintilla.Notification->Nmhdr.Code = N_FILEBEFORESAVE;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = BufferID;

  N_FILESAVED : constant := N_FIRST + 8;
  -- To notify plugins that the current file is just saved
  -- Scintilla.Notification->Nmhdr.Code = N_FILESAVED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = BufferID;

  N_SHUTDOWN : constant := N_FIRST + 9;
  -- To notify plugins that Notepad++ is about to be shutdowned.
  -- Scintilla.Notification->Nmhdr.Code = N_SHUTDOWN;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = 0;

  N_BUFFERACTIVATED : constant := N_FIRST + 10;
  -- To notify plugins that a buffer was activated (put to foreground).
  -- Scintilla.Notification->Nmhdr.Code = NPPN_BUFFERACTIVATED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = activatedBufferID;

  N_LANGCHANGED : constant := N_FIRST + 11;
  -- To notify plugins that the language in the current doc is just changed.
  -- Scintilla.Notification->Nmhdr.Code = N_LANGCHANGED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = currentBufferID;

  N_WORDSTYLESUPDATED : constant := N_FIRST + 12;
  -- To notify plugins that user initiated a WordStyleDlg change.
  -- Scintilla.Notification->Nmhdr.Code = N_WORDSTYLESUPDATED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = currentBufferID;

  N_SHORTCUTREMAPPED : constant := N_FIRST + 13;
  -- To notify plugins that plugin command shortcut is remapped.
  -- Scintilla.Notification->Nmhdr.Code = N_SHORTCUTSREMAPPED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = ShortcutKeyStructurePointer;
  -- Scintilla.Notification->Nmhdr.Id_From = cmdID;
  -- where ShortcutKeyStructurePointer is pointer of struct ShortcutKey

  N_FILEBEFORELOAD : constant := N_FIRST + 14;
  -- To notify plugins that the current file is about to be loaded
  -- Scintilla.Notification->Nmhdr.Code = NPPN_FILEBEFOREOPEN;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = NULL;

  N_FILELOADFAILED : constant := N_FIRST + 15;
  -- To notify plugins that file open operation failed
  -- Scintilla.Notification->Nmhdr.Code = NPPN_FILEOPENFAILED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = hwndNpp;
  -- Scintilla.Notification->Nmhdr.Id_From = BufferID;

  N_READONLYCHANGED : constant := N_FIRST + 16;
  -- To notify plugins that current document change the readonly status,
  -- Scintilla.Notification->Nmhdr.Code = N_READONLYCHANGED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = bufferID;
  -- Scintilla.Notification->Nmhdr.Id_From = docStatus;
  -- where bufferID is BufferID
  -- and docStatus can be combined by DOCSTAUS_READONLY and DOCSTAUS_BUFFERDIRTY

  DOCSTAUS_READONLY    : constant := 1;
  DOCSTAUS_BUFFERDIRTY : constant := 2;

  N_DOCORDERCHANGED : constant := N_FIRST + 16;
  -- To notify plugins that document order is changed
  -- Scintilla.Notification->Nmhdr.Code = N_DOCORDERCHANGED;
  -- Scintilla.Notification->Nmhdr.Hwnd_From = newIndex;
  -- Scintilla.Notification->Nmhdr.Id_From = BufferID;

end Npp;